==> qiho-center-api-1.0.3-sources.jar: com/qiho/center/api/params/ErpOrderPageParams.java <==
package com.qiho.center.api.params;

import com.qiho.center.api.enums.DeliveryEnum;
import com.qiho.center.api.enums.ErpStatusEnum;

import java.util.Date;
import java.util.Map;

/**
 * Created by liuyao on 2017/6/10.
 * ERP子订单分页查询
 */
public class ErpOrderPageParams extends PageQueryParams {

    private static final long serialVersionUID = 7342240861234028993L;
    private String orderId;
    private String erpId;
    private String skuNo;//商品编码
    private String itemNo;
    private String itemId;//商品Id
    private String itemName;//商品名称
    private String consumerName;//用户名称
    private String mobile;
    private Date startTime;
    private Date endTime;
    private String erpStatus;
    private String delivery;

    public String getOrderId() {
        return orderId;
    }

    public void setOrderId(String orderId) {
        this.orderId = orderId;
    }

    public String getErpId() {
        return erpId;
    }

    public void setErpId(String erpId) {
        this.erpId = erpId;
    }

    public String getSkuNo() {
        return skuNo;
    }

    public void setSkuNo(String skuNo) {
        this.skuNo = skuNo;
    }

    public String getItemNo() {
        return itemNo;
    }

    public void setItemNo(String itemNo) {
        this.itemNo = itemNo;
    }

    public String getItemId() {
        return itemId;
    }

    public void setItemId(String itemId) {
        this.itemId = itemId;
    }

    public String getItemName() {
        return itemName;
    }

    public void setItemName(String itemName) {
        this.itemName = itemName;
    }

    public String getConsumerName() {
        return consumerName;
    }

    public void setConsumerName(String consumerName) {
        this.consumerName = consumerName;
    }

    public String getMobile() {
        return mobile;
    }

    public void setMobile(String mobile) {
        this.mobile = mobile;
    }

    public Date getStartTime() {
        return startTime;
    }

    public void setStartTime(Date startTime) {
        this.startTime = startTime;
    }

    public Date getEndTime() {
        return endTime;
    }

    public void setEndTime(Date endTime) {
        this.endTime = endTime;
    }

    public String getErpStatus() {
        return erpStatus;
    }

    public void setErpStatus(String erpStatus) {
        this.erpStatus = erpStatus;
    }

    public String getDelivery() {
        return delivery;
    }

    public void setDelivery(String delivery) {
        this.delivery = delivery;
    }
}

==> qiho-center-api-2.9.6-20210525.064243-1-sources.jar: com/qiho/center/api/params/ErpOrderPageParams.java <==
package com.qiho.center.api.params;

import java.util.Date;

/**
 * Created by liuyao on 2017/6/10.
 * ERP子订单分页查询
 */
public class ErpOrderPageParams extends PageQueryParams {

    private static final long serialVersionUID = 7342240861234028993L;
    private String orderId;
    private String erpId;
    private String skuNo;//商品编码
    private String itemNo;
    private String itemId;//商品Id
    private String itemName;//商品名称
    private String consumerName;//用户名称
    private String mobile;
    private Date startTime;
    private Date endTime;
    private String erpStatus;
    private String delivery;
    private Long merchantId;
    private String erpType;


    public String getOrderId() {
        return orderId;
    }

    public void setOrderId(String orderId) {
        this.orderId = orderId;
    }

    public String getErpId() {
        return erpId;
    }

    public void setErpId(String erpId) {
        this.erpId = erpId;
    }

    public String getSkuNo() {
        return skuNo;
    }

    public void setSkuNo(String skuNo) {
        this.skuNo = skuNo;
    }

    public String getItemNo() {
        return itemNo;
    }

    public void setItemNo(String itemNo) {
        this.itemNo = itemNo;
    }

    public String getItemId() {
        return itemId;
    }

    public void setItemId(String itemId) {
        this.itemId = itemId;
    }

    public String getItemName() {
        return itemName;
    }

    public void setItemName(String itemName) {
        this.itemName = itemName;
    }

    public String getConsumerName() {
        return consumerName;
    }

    public void setConsumerName(String consumerName) {
        this.consumerName = consumerName;
    }

    public String getMobile() {
        return mobile;
    }

    public void setMobile(String mobile) {
        this.mobile = mobile;
    }

    public Date getStartTime() {
        return startTime;
    }

    public void setStartTime(Date startTime) {
        this.startTime = startTime;
    }

    public Date getEndTime() {
        return endTime;
    }

    public void setEndTime(Date endTime) {
        this.endTime = endTime;
    }

    public String getErpStatus() {
        return erpStatus;
    }

    public void setErpStatus(String erpStatus) {
        this.erpStatus = erpStatus;
    }

    public String getDelivery() {
        return delivery;
    }

    public void setDelivery(String delivery) {
        this.delivery = delivery;
    }

    public Long getMerchantId() {
        return merchantId;
    }

    public void setMerchantId(Long merchantId) {
        this.merchantId = merchantId;
    }

    public String getErpType() {
        return erpType;
    }

    public void setErpType(String erpType) {
        this.erpType = erpType;
    }
}
